@@ -12,12 +12,14 @@
 # You should have received a copy of the GNU General Public
 # License along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-import json
 import logging
 from functools import partial
 from Queue import Queue
 from weakref import ref
 from threading import Lock, Event
+
+from vdsm.compat import json
+
 from vdsm.utils import traceback
 
 __all__ = ["tcpReactor"]
