@@ -204,6 +204,7 @@ class Bond(NetDevice):
         # is already applied in any way, we can skip the configuring.
         if (self.vlan and
             self.name in netinfo.bondings() and
+            self.name in self.configurator.runningConfig.bonds and
             netinfo.operstate(self.name) == netinfo.OPERSTATE_UP and
             netinfo.ifaceUsed(self.name) and
             self.mtu <= netinfo.getMtu(self.name) and
@@ -263,9 +264,6 @@ class Bond(NetDevice):
             raise ConfigNetworkError(ne.ERR_BAD_PARAMS,
                                      'Missing required nics on a bonding %s '
                                      'that is unknown to Vdsm ' % name)
-        if not slaves:
-            raise ConfigNetworkError(ne.ERR_BAD_PARAMS, 'Missing required nics'
-                                     ' for bonding device.')
 
         return cls(name, configurator, slaves=slaves, options=options, mtu=mtu,
                    destroyOnMasterRemoval=destroyOnMasterRemoval)
